@@ -36,8 +36,12 @@
 ##' "importance" uses an importance sampling algorithm with an importance
 ##' distribution that is multivariate normal on log(g). "laplace" does not
 ##' sample, but uses a Laplace approximation to the integral. It is expected to
-##' be more accurate for large sample sizes, where MC sampling is slow. 
-##' integration, and the posterior is sampled with a Gibbs sampler.
+##' be more accurate for large sample sizes, where MC sampling is slow. If 
+##' \code{method="auto"}, then an initial run with both samplers is done, and
+##' the sampling method that yields the least-variable samples is chosen. The number 
+##' of initial test iterations is determined by \code{options(BFpretestIterations)}.
+##' 
+##' If posterior samples are requested, the posterior is sampled with a Gibbs sampler.
 ##' @title Use ANOVA design matrix to compute Bayes factors or sample posterior
 ##' @param y vector of observations
 ##' @param X design matrix whose number of rows match \code{length(y)}.
@@ -53,7 +57,10 @@
 ##' @param gibbs if \code{TRUE}, return samples from the posterior instead of a 
 ##'   Bayes factor
 ##' @param method the integration method (only valid if \code{gibbs=TRUE}); one 
-##'   of "simple", "importance", "laplace"
+##'   of "simple", "importance", "laplace", or "auto"
+##' @param continuous either FALSE is no continuous covariates are included, or a 
+##' logical vector of length equal to number of columns of X indicating which
+##' columns of the design matrix represent continuous covariates  
 ##' @return If \code{posterior} is \code{FALSE}, a vector of length 2 containing
 ##'   the computed log(e) Bayes factor (against the intercept-only null), along 
 ##'   with a proportional error estimate on the Bayes factor. Otherwise, an 
@@ -92,11 +99,13 @@
 ##' bf.full2 <- lmBF(extra ~ group + ID, data = sleep, whichRandom = "ID")
 ##' bf.full2
 
-nWayAOV<- function(y, X, struc = NULL, gMap = NULL, rscale, iterations = 10000, progress = TRUE, gibi = NULL, gibbs = FALSE, method="simple")
-{
+nWayAOV<- function(y, X, struc = NULL, gMap = NULL, rscale, iterations = 10000, progress = TRUE, gibi = NULL, gibbs = FALSE, method="auto", continuous=FALSE)
+{  
   if(!is.numeric(y)) stop("y must be numeric.")  
   if(!is.numeric(X)) stop("X must be numeric.")  
   
+  apx = NULL
+  
   N = length(y)
 	X = matrix( X, nrow=N )
   
@@ -126,13 +135,6 @@ nWayAOV<- function(y, X, struc = NULL, gMap = NULL, rscale, iterations = 10000,
     stop("One of gMap or struc must be defined.")
   }
   
-  C = diag(N) - matrix(1/N,N,N)
-  Cy = y - mean(y)
-  CX = C %*% X
-  XtCX = t(X) %*% CX
-  XtCy = t(X) %*% C %*% as.matrix(y,cols=1)
-  ytCy = var(y)*(N-1)
-  
   a = rep(0.5,nGs)
   if(length(rscale)==nGs){
     b = rscale^2/2
@@ -140,6 +142,53 @@ nWayAOV<- function(y, X, struc = NULL, gMap = NULL, rscale, iterations = 10000,
     stop("Length of rscale vector wrong. Was ", length(rscale), " and should be ", nGs,".")
   }
   
+  
+  #C = diag(N) - matrix(1/N,N,N)
+  Cy = y - mean(y)
+  #CX = C %*% X
+  CX = apply(X,2,function(v) v - mean(v))
+  
+  # Rearrange design matrix if continuous columns are included
+  # We will undo this later if chains have to be returned
+  if(!identical(continuous,FALSE)){
+    if(all(continuous)){
+      #### If all covariates are continuous, we want to use Gaussian quadrature.
+      #warning("All covariates are continuous: using Gaussian quadrature.")
+      if(gibbs){
+        chains = linearReg.Gibbs(y, X, iterations = iterations, 
+                                 rscale = rscale, progress = progress, 
+                                 gibi=gibi)
+        return(chains)
+      }else{
+        R2 = t(y)%*%X%*%solve(t(X)%*%X)%*%t(X)%*%y / (t(y)%*%y)
+        bf = linearReg.R2stat(N=N,p=ncol(X),R2=R2,rscale=rscale)  
+        return(bf)
+      }
+    } 
+    if(length(continuous) != P) stop("argument continuous must have same length as number of predictors")
+    if(length(unique(gMap[continuous]))!=1) stop("gMap for continuous predictors don't all point to same g value")
+    sortX = order(!continuous)
+    revSortX = order(sortX)
+    CX = CX[,sortX]
+    gMap = gMap[sortX]
+    incCont = sum(continuous)
+    if(incCont>1){
+      CX[,1:incCont]
+      priorX = (t(CX[,1:incCont]) %*% CX[,1:incCont])/N
+    }else{
+      priorX = sum(CX[,1]^2)/N
+    }
+  }else{
+    incCont = 0
+    priorX = 1
+  }
+  
+  XtCX = t(CX) %*% CX
+  #XtCy = t(CX) %*% C %*% as.matrix(y,cols=1)
+  XtCy = t(CX) %*% as.matrix(y,cols=1)
+  ytCy = var(y)*(N-1)
+  
+
 	nullLike = - ((N-1)/2)*log((N-1)*var(y))
 	
   
@@ -169,46 +218,34 @@ nWayAOV<- function(y, X, struc = NULL, gMap = NULL, rscale, iterations = 10000,
   
   
   if(gibbs){ # Create chains
-    Z = cbind(1,X)
+    Z = cbind(1,CX)
     ZtZ = t(Z)%*%Z
     Zty = t(Z)%*%matrix(y,ncol=1)
     
     chains = .Call("RGibbsNwayAov", 
-                   as.integer(iterations), y, Z, ZtZ, Zty, as.integer(N), 
-                   as.integer(P), as.integer(nGs), as.integer(gMap), rscale,
+                   as.integer(iterations), y, Z, ZtZ, priorX, Zty, as.integer(N), 
+                   as.integer(P), as.integer(nGs), as.integer(gMap), rscale, as.integer(incCont),
                    as.integer(iterations/100*progress), pbFun, new.env(), 
                    package="BayesFactor")
     
     dim(chains) <- c(2 + P + nGs, iterations)
     chains = mcmc(t(chains))  
+    # Unsort the chains if we had continuous covariates
+    if(incCont){
+      chains[,1 + 1:P] = chains[,1+revSortX]
+    }  
     labels = c("mu",paste("beta",1:P,sep="_"),"sig2",paste("g",1:nGs,sep="_"))
     colnames(chains) = labels
     retVal = chains
  
   }else{ # Compute Bayes factor
-    if(method=="simple"){
-      returnList = .Call("RjeffSamplerNwayAov", 
-                     as.integer(iterations), XtCX, XtCy, ytCy, 
-                     as.integer(N), 
-                     as.integer(P), 
-                     as.integer(nGs), 
-                     as.integer(gMap), a, b,
-                     as.integer(iterations/100*progress), 
-                     pbFun, new.env(), 
-                     package="BayesFactor")
-    }else if(method=="importance"){
-      apx = gaussianApproxAOV(y,X,rscale,gMap)
-      returnList = .Call("RimportanceSamplerNwayAov", 
-                         as.integer(iterations), XtCX, XtCy, ytCy, 
-                         as.integer(N), 
-                         as.integer(P), 
-                         as.integer(nGs), 
-                         as.integer(gMap), a, b, apx$mu, apx$sig,
-                         as.integer(iterations/100*progress), 
-                         pbFun, new.env(), 
-                         package="BayesFactor")
+    if(method %in% c("simple","importance","auto")){
+      retVal = doNwaySampling(method, y, X, rscale, nullLike, 
+                   as.integer(iterations), XtCX, priorX, XtCy, ytCy, 
+                   as.integer(N), as.integer(P), as.integer(nGs), 
+                   as.integer(gMap), a, b, as.integer(incCont), progress, pbFun)
     }else if(method=="laplace"){
-      bf = laplaceAOV(y,X,rscale,gMap)
+      bf = laplaceAOV(y,X,rscale,gMap,priorX,incCont)
       properror=NA
       retVal = c(bf = bf, properror=properror)
       if(inherits(pb,"txtProgressBar")) close(pb);
@@ -216,13 +253,6 @@ nWayAOV<- function(y, X, struc = NULL, gMap = NULL, rscale, iterations = 10000,
     }else{  
       stop("Unknown method specified.")
     }
-    bf = returnList[[1]] - nullLike
-    
-    # estimate error
-    bfSamp = returnList[[2]] - nullLike
-    properror = propErrorEst(bfSamp)
-    
-    retVal = c(bf = bf, properror=properror)
   }
   
   if(inherits(pb,"txtProgressBar")) close(pb);
